==> estateplat-common-1.2.4-20200121.081003-258-sources.jar: cn/gtmap/estateplat/model/information/core/XxSjcl.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2019-12-17
 * @description 项目收件材料
 */
@Table(name = "xx_sjcl")
public class XxSjcl implements InsertVo, Comparable<XxSjcl> {
    @Id
    private String sjclid;//主键
    private String proid;//项目表主键
    private Integer xh;//序号
    private String clmc;//材料名称GD_FW_QL
    private int sl;//数量
    private String cllx;
    private String bz;// 备注

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public int getSl() {
        return sl;
    }

    public void setSl(int sl) {
        this.sl = sl;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @Override
    public int compareTo(XxSjcl o) {
        return this.xh.compareTo(o.getXh());
    }
}

==> estateplat-common-1.2.4-20210429.073526-738-sources.jar: cn/gtmap/estateplat/model/information/core/XxSjcl.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2019-12-17
 * @description 项目收件材料
 */
@Table(name = "xx_sjcl")
public class XxSjcl implements InsertVo, Comparable<XxSjcl> {
    @Id
    private String sjclid;//主键
    private String proid;//项目表主键
    private Integer xh;//序号
    private String clmc;//材料名称
    private int sl;//数量
    private String cllx;
    private String bz;// 备注

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public int getSl() {
        return sl;
    }

    public void setSl(int sl) {
        this.sl = sl;
    }

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @Override
    public int compareTo(XxSjcl o) {
        return this.xh.compareTo(o.getXh());
    }
}
